#!/usr/bin/python
import sys
import time
import numpy as np
import matplotlib
#matplotlib.use('Agg')
import matplotlib.pyplot as plt
import csv
import scipy.ndimage.filters
import scipy.interpolate

mfc_name = "DUT"
meter_name = "3458A"
real_row = 2

if len(sys.argv) < 2:
    print("Need an argument! <file_name> [<data_row_number>] [<dut_name>] [<meter_name>]")
    quit()

if len(sys.argv) >= 3:
    real_row = int(sys.argv[2])

if len(sys.argv) >= 4:
    chart_name = sys.argv[3]

if len(sys.argv) == 5:
    meter_name = sys.argv[4]

fn = sys.argv[1]

ideal = []
real = []
real2 = []
real3 = []
real4 = []
real5 = []

with open(fn) as csvfile:
    spamreader = csv.reader(csvfile, delimiter=';', quotechar='|')
    is_first = True
    for row in spamreader:
        if is_first:
            is_first = False
            continue
        #print ("%f" % float(row[1]))
        ideal.extend([float(row[2])])
        real.extend([float(row[1])])
        real2.extend([float(row[3])])
        real3.extend([float(row[4])])
        real4.extend([float(row[5])])
        real5.extend([float(row[2])])

p = np.polyfit(real,ideal,1)
pv = np.polyval(p,real)
diff = ideal-pv
diff_ppm = (diff/1)*1000000.0

p2 = np.polyfit(real2,ideal,1)
pv2 = np.polyval(p2,real2)
diff2 = ideal-pv2
diff_ppm2 = (diff2/1)*1000000.0

p3 = np.polyfit(real3,ideal,1)
pv3 = np.polyval(p3,real3)
diff3 = ideal-pv3
diff_ppm3 = (diff3/1.0)*1000000.0

p4 = np.polyfit(real4,ideal,1)
pv4 = np.polyval(p4,real4)
diff4 = ideal-pv4
diff_ppm4 = (diff4/1)*1000000.0

p5 = np.polyfit(real5,ideal,1)
pv5 = np.polyval(p5,real5)
diff5 = ideal-pv5
diff_ppm5 = (diff5/1)*1000000.0

#diff_ppm6 = diff_ppm5 - diff_ppm #(diff3/10.0)*1000000.0
#diff_ppm7 = diff_ppm5 - diff_ppm3 #(diff3/10.0)*1000000.0

inl_max = np.amax(diff_ppm)
inl_min = np.amin(diff_ppm)
inl_delta = inl_max - inl_min
inl_span = inl_delta / 2.0

#print(chart_name + " INL Max: %f, Min %f" % (inl_max , inl_min))
#print(chart_name + " INL +-%f" % inl_span)

fig, ax = plt.subplots()
idx = 1
colors = ['#641e11','#11ae33','#3344ff','#ff3311','#77ae3e','#c56ac1','#777777']

ax.patch.set_facecolor('#eeeeff')
ax.set_clip_on(False)

w = 20
h = 9
fig.set_size_inches(w,h)
plt.tight_layout(rect=[0.02, 0.02, 1.0, 0.98], w_pad=0, h_pad=0.5)                                # Reduce margins around the graph

filtered1 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm, sigma=2)
filtered2 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm2, sigma=2)
filtered3 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm3, sigma=2)
filtered4 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm4, sigma=2)
filtered5 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm5, sigma=2)
#filtered6 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm6, sigma=2)
#filtered7 = scipy.ndimage.filters.gaussian_filter1d(diff_ppm7, sigma=2)

#for diff_ppm in diff_ppms:
#ax.plot(ideal, diff_ppm)
ax.plot(ideal, filtered1, colors[1], label='Data %i' % (0), linewidth=3.0)
ax.plot(ideal, filtered2, colors[3], label='Data %i' % (1), linewidth=3.0)
ax.plot(ideal, filtered3, colors[2], label='Data %i' % (2), linewidth=3.0)
ax.plot(ideal, filtered4, colors[5], label='Data %i' % (4), linewidth=3.0)
ax.plot(ideal, filtered5, colors[6], label='Data %i' % (5), linewidth=5.0)
#ax.plot(ideal, filtered6, colors[5], label='Data %i' % (6), linewidth=2.0)
#ax.plot(ideal, filtered7, colors[6], label='Data %i' % (7), linewidth=2.0)
#    idx = idx + 1
#plt.text(-0.105, 1.01, "xDevs.com", fontsize=15)
#plt.text(-0.105, -1.11, "https://github.com/tin-/linkit", fontsize=13)

ax.axis([-1.0, 1.0, -30.0, 30.0])

ax.legend(['2460 vs Burster 1 Ohm shunt', '2460 vs K34470A', '2460 vs K7510', '2460 vs A3458', 'Baseline', 'na', 'na'])

start, end = ax.get_ylim()
stepsize = 1
ax.yaxis.set_ticks(np.arange(start, end, stepsize))
startx, endx = ax.get_xlim()
stepsizex = 0.1
ax.xaxis.set_ticks(np.arange(startx, endx, stepsizex))

ax.set(xlabel='Current, ADC', ylabel='INL, ppm of best-fit poly 1000 mA',
       title='%s' % (chart_name))
ax.grid()

fig.savefig("test_hv2460_brs1.png", facecolor=fig.get_facecolor(), transparent=False)
plt.show()

